# 2009 Edition

# Table 6—Minimum Thicknesses for Carbon and Low-alloy Steel Pipe
# API 574-2009 Standard

API574_2009_TABLE_6 = {
    "0.5":  {"default_minimum_structural_thickness": 0.07, "minimum_alert_thickness": 0.08},
    "0.75": {"default_minimum_structural_thickness": 0.07, "minimum_alert_thickness": 0.08},
    "1":    {"default_minimum_structural_thickness": 0.07, "minimum_alert_thickness": 0.08},
    "1.5":  {"default_minimum_structural_thickness": 0.07, "minimum_alert_thickness": 0.09},
    "2":    {"default_minimum_structural_thickness": 0.07, "minimum_alert_thickness": 0.10},
    "3":    {"default_minimum_structural_thickness": 0.08, "minimum_alert_thickness": 0.11},
    "4":    {"default_minimum_structural_thickness": 0.09, "minimum_alert_thickness": 0.12},
    "6":    {"default_minimum_structural_thickness": 0.11, "minimum_alert_thickness": 0.13},
    "8":    {"default_minimum_structural_thickness": 0.11, "minimum_alert_thickness": 0.13},
    "10":   {"default_minimum_structural_thickness": 0.11, "minimum_alert_thickness": 0.13},
    "12":   {"default_minimum_structural_thickness": 0.11, "minimum_alert_thickness": 0.13},
    "14":   {"default_minimum_structural_thickness": 0.11, "minimum_alert_thickness": 0.13},
    "16":   {"default_minimum_structural_thickness": 0.11, "minimum_alert_thickness": 0.13},
    "18":   {"default_minimum_structural_thickness": 0.11, "minimum_alert_thickness": 0.13},
    "20":   {"default_minimum_structural_thickness": 0.12, "minimum_alert_thickness": 0.14},
    "24":   {"default_minimum_structural_thickness": 0.12, "minimum_alert_thickness": 0.14},
}

